@@ -11,21 +11,19 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from dataclasses import dataclass
-from typing import Any, Dict, Optional
-
-from dataclasses_json import LetterCase, dataclass_json
+import dataclasses
+from typing import Optional
 
+import dataclasses_json
 from card_framework import standard_field
 
-from ..widget import Widget
 from .color import Color
 from .icon import Icon
 from .on_click import OnClick
 
 
-@dataclass_json(letter_case=LetterCase.CAMEL)
-@dataclass
+@dataclasses_json.dataclass_json
+@dataclasses.dataclass
 class Button(object):
   """Button
 
