@@ -11,14 +11,14 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from dataclasses import dataclass
+import dataclasses
 
+import dataclasses_json
 from card_framework import AutoNumber, enum_field, standard_field
-from dataclasses_json import LetterCase, dataclass_json
 
 
-@dataclass_json(letter_case=LetterCase.CAMEL)
-@dataclass
+@dataclasses_json.dataclass_json
+@dataclasses.dataclass
 class OpenLink(object):
   class OnClose(AutoNumber):
     """OnClose
