@@ -11,11 +11,10 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from dataclasses import dataclass
+import dataclasses
 from typing import List, Optional
 
-from dataclasses_json import LetterCase, dataclass_json
-
+import dataclasses_json
 from card_framework import AutoNumber, enum_field, list_field, standard_field
 
 from ..widget import Widget
@@ -23,8 +22,8 @@ from .action import Action
 from .selection_item import SelectionItem
 
 
-@dataclass_json(letter_case=LetterCase.CAMEL)
-@dataclass
+@dataclasses_json.dataclass_json
+@dataclasses.dataclass
 class SelectionInput(Widget):
   """SelectionInput
   """
