@@ -11,20 +11,20 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from dataclasses import dataclass
+import dataclasses
 from typing import List
 
 from card_framework import standard_field
-from dataclasses_json import (LetterCase, dataclass_json)
+import dataclasses_json
 
 
-@dataclass_json(letter_case=LetterCase.CAMEL)
-@dataclass
+@dataclasses_json.dataclass_json
+@dataclasses.dataclass
 class SuggestionItem(object):
   text: str = standard_field()
 
 
-@dataclass_json(letter_case=LetterCase.CAMEL)
-@dataclass
+@dataclasses_json.dataclass_json
+@dataclasses.dataclass
 class Suggestions(object):
   items: List[SuggestionItem] = standard_field()
