@@ -11,19 +11,19 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from dataclasses import dataclass
+import dataclasses
 from typing import Optional
 
 from card_framework import AutoNumber, enum_field, standard_field
-from dataclasses_json import LetterCase, dataclass_json
+import dataclasses_json
 
 from ..widget import Widget
 from .action import Action
 from .suggestions import Suggestions
 
 
-@dataclass_json(letter_case=LetterCase.CAMEL)
-@dataclass
+@dataclasses_json.dataclass_json
+@dataclasses.dataclass
 class TextInput(Widget):
   """TextInput
   """
